aboutsummaryrefslogtreecommitdiff
path: root/nx-X11/programs/Xserver/os/oscolor.c
diff options
context:
space:
mode:
Diffstat (limited to 'nx-X11/programs/Xserver/os/oscolor.c')
-rw-r--r--nx-X11/programs/Xserver/os/oscolor.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/nx-X11/programs/Xserver/os/oscolor.c b/nx-X11/programs/Xserver/os/oscolor.c
index 8f737eaba..2ea81060d 100644
--- a/nx-X11/programs/Xserver/os/oscolor.c
+++ b/nx-X11/programs/Xserver/os/oscolor.c
@@ -134,11 +134,11 @@ OsLookupColor(int screen, char *name, unsigned int len,
if(!rgb_dbm)
return(0);
/* we use xalloc here so that we can compile with cc without alloca
* when otherwise using gcc */
if (len < sizeof(buf))
lowername = buf;
- else if (!(lowername = (char *)xalloc(len + 1)))
+ else if (!(lowername = (char *)malloc(len + 1)))
return(0);
CopyISOLatin1Lowered ((unsigned char *) lowername, (unsigned char *) name,
(int)len);
@@ -372,7 +372,7 @@ lookup(char *name, int len, Bool create)
else
prev = &(hashTab[h]);
- if (!entry && create && (entry = (dbEntryPtr)xalloc(sizeof(dbEntry) +len)))
+ if (!entry && create && (entry = (dbEntryPtr)malloc(sizeof(dbEntry) +len)))
{
*prev = entry;
entry->link = NULL;
@@ -134,11 +134,11 @@ OsLookupColor(int screen, char *name, unsigned int len,
if(!rgb_dbm)
return(0);
- /* we use xalloc here so that we can compile with cc without alloca
+ /* we use malloc here so that we can compile with cc without alloca
* when otherwise using gcc */
if (len < sizeof(buf))